==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/TimeAxisBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CategoryAxisBaseDescriptionMetadata } from "./CategoryAxisBaseDescriptionMetadata";
/**
 * @hidden
 */
export let TimeAxisBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class TimeAxisBaseDescriptionMetadata extends Base {
        static b(a) {
            if (TimeAxisBaseDescriptionMetadata.a == null) {
                TimeAxisBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TimeAxisBaseDescriptionMetadata.c(TimeAxisBaseDescriptionMetadata.a);
            }
            if (a.j(TimeAxisBaseDescriptionMetadata.a)) {
                return;
            }
            a.y(TimeAxisBaseDescriptionMetadata.a);
        }
        static c(a) {
            CategoryAxisBaseDescriptionMetadata.c(a);
            a.item("DateTimeMemberPath", "String");
            a.item("IsDataPreSorted", "Boolean");
            a.item("ActualMinimumValue", "Date");
            a.item("ActualMaximumValue", "Date");
            a.item("MinimumValue", "Date");
            a.item("MaximumValue", "Date");
            a.item("ActualMinimumValueChangeRef", "EventRef::actualMinimumValueChange");
            a.item("ActualMaximumValueChangeRef", "EventRef::actualMaximumValueChange");
        }
        static d(a) {
            TimeAxisBaseDescriptionMetadata.b(a);
            a.z("TimeAxisBase", TimeAxisBaseDescriptionMetadata.a);
        }
    }
    TimeAxisBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(TimeAxisBaseDescriptionMetadata, 'TimeAxisBaseDescriptionMetadata');
    TimeAxisBaseDescriptionMetadata.a = null;
    return TimeAxisBaseDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/TimeAxisBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CategoryAxisBaseDescriptionMetadata } from "./CategoryAxisBaseDescriptionMetadata";
/**
 * @hidden
 */
export let TimeAxisBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class TimeAxisBaseDescriptionMetadata extends Base {
        static b(a) {
            if (TimeAxisBaseDescriptionMetadata.a == null) {
                TimeAxisBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TimeAxisBaseDescriptionMetadata.c(TimeAxisBaseDescriptionMetadata.a);
            }
            if (a.k(TimeAxisBaseDescriptionMetadata.a)) {
                return;
            }
            a.aa(TimeAxisBaseDescriptionMetadata.a);
        }
        static c(a) {
            CategoryAxisBaseDescriptionMetadata.c(a);
            a.item("DateTimeMemberPath", "String");
            a.item("IsDataPreSorted", "Boolean");
            a.item("ActualMinimumValue", "Date");
            a.item("ActualMaximumValue", "Date");
            a.item("MinimumValue", "Date");
            a.item("MaximumValue", "Date");
            a.item("ActualMinimumValueChangeRef", "EventRef::actualMinimumValueChange");
            a.item("ActualMaximumValueChangeRef", "EventRef::actualMaximumValueChange");
        }
        static d(a) {
            TimeAxisBaseDescriptionMetadata.b(a);
            a.ab("TimeAxisBase", TimeAxisBaseDescriptionMetadata.a);
        }
    }
    TimeAxisBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(TimeAxisBaseDescriptionMetadata, 'TimeAxisBaseDescriptionMetadata');
    TimeAxisBaseDescriptionMetadata.a = null;
    return TimeAxisBaseDescriptionMetadata;
})();
